what.attacks API documentation

# what.attacks

This module implements several white-box attacks against Deep Learning models.

Use `what attack list` to list available attacks:

    1 : TOG Attack  Object Detection
    2 : PCB Attack  Object Detection

## what.attacks.detection.yolo.PCB

- A Man-in-the-Middle Attack against Object Detection Systems.

## what.attacks.detection.yolo.TOG

- Adversarial Objectness Gradient Attacks in Real-time Object Detection Systems.

View Source

     1r'''
     2This module implements several white-box attacks against Deep Learning models.
     3
     4Use `what attack list` to list available attacks:
     5
     6```
     71 : TOG Attack  Object Detection
     82 : PCB Attack  Object Detection
     9```
    10
    11<br />
    12
    13## what.attacks.detection.yolo.PCB
    14
    15- [A Man-in-the-Middle Attack against Object Detection Systems](https://arxiv.org/abs/2208.07174).
    16
    17## what.attacks.detection.yolo.TOG
    18
    19- [Adversarial Objectness Gradient Attacks in Real-time Object Detection Systems](https://ieeexplore.ieee.org/document/9325397).
    20
    21'''
    22
    23from what.attacks.detection.yolo.PCB import PCBAttack
    24from what.attacks.detection.yolo.TOG import TOGAttack